@@ -19,12 +19,12 @@ def set_rand_state(RAND_STATE):
     random.seed(RAND_STATE)
     return None
     
-def train_gridsearch_classifier(umap_df,test_size=0.3,num_CV=5):
+def train_gridsearch_classifier(umap_df,test_size=0.3,num_CV=5,verbosity=0):
     UMAP_X = np.stack(umap_df['waveform'].to_numpy().tolist(), axis=0)
     UMAP_y = umap_df['cluster_id'].to_numpy()
     UMAP_X_train, UMAP_X_test, UMAP_y_train, UMAP_y_test = train_test_split(UMAP_X,     UMAP_y, test_size=test_size, random_state=RAND_STATE)
 
-    UMAP_model = xgb.XGBClassifier(objective='multi:softmax')
+    UMAP_model = xgb.XGBClassifier(objective='multi:softmax',verbosity=verbosity)
     UMAP_param_dist = {"max_depth": [3,5,10],
                   "min_child_weight" : [1.0,2.5,5.0],
                   "n_estimators": [10,25,50,100,200],
